@@ -229,7 +229,7 @@ class AggregatorStub(object):
             msg = "The metric '{}' with tag '{}' was only found {}/{} times".format(metric_name, tag, count, at_least)
         elif candidates:
             msg = (
-                "The metric '{}' was found but not with the tag '{}'.\n"
+                "The metric '{}' was found but not with the tag '{}'.\n".format(metric_name, tag)
                 + "Similar submitted:\n"
                 + "\n".join(["     {}".format(m) for m in candidates])
             )
